#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-call-hierarchy-plugin
version:              2.2.0.0
visibility:           public
id:                   hls-call-hierarchy-plugin-2.2.0.0-Cuo4RpAZMt6vuGJSxNL1A
key:                  hls-call-hierarchy-plugin-2.2.0.0-Cuo4RpAZMt6vuGJSxNL1A
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Call hierarchy plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-call-hierarchy-plugin#readme>

category:             Development
abi:                  832f431a04bcf1e3bc6b38263915a016
exposed:              True
exposed-modules:      Ide.Plugin.CallHierarchy
hidden-modules:
    Ide.Plugin.CallHierarchy.Internal Ide.Plugin.CallHierarchy.Query
    Ide.Plugin.CallHierarchy.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.2.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.2.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-call-hierarchy-plugin-2.2.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-call-hierarchy-plugin
hs-libraries:         HShls-call-hierarchy-plugin-2.2.0.0-Cuo4RpAZMt6vuGJSxNL1A
depends:
    aeson-2.2.1.0-B4RqQZAnAt5HkJbmyrGfNz base-4.18.2.1 containers-0.6.7
    extra-1.7.16-5wibn5p3dDHK0RAEHmHjOt
    ghcide-2.2.0.0-LTYSQCPFpXhKThfiL7WDD7
    hiedb-0.4.3.0-5Wb6U7OoC3TJVHk3JRwuaa
    hls-plugin-api-2.2.0.0-8GCb8iO3kpmLV9RcpzJ7mb
    lens-5.3.3-CrNUPavyVUO9ykk7YePBEi lsp-2.2.0.0-eMvV3FRX9gCFGO6PEmJjh
    sqlite-simple-0.4.19.0-BeMrmjiRQgCF8dc3ZPno8b text-2.0.2
    unordered-containers-0.2.20.1-C4c13QuwLgs7TJHWi6VHCN

haddock-interfaces:
    /usr/share/doc/haskell-hls-call-hierarchy-plugin/html/hls-call-hierarchy-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-call-hierarchy-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

